@@ -31,7 +31,7 @@ func TestParse(t *testing.T) {
 			Hostname: "192.168.122.1:6233",
 			Path:     "/",
 			Query: map[string][]string{
-				"abc": []string{"def"},
+				"abc": {"def"},
 			},
 		},
 
@@ -230,6 +230,87 @@ func TestParse(t *testing.T) {
 			Hostname: "192.168.122.1",
 			Path:     "",
 		},
+
+		// ibmc
+		{
+			Scenario: "ibmc url",
+			Address:  "ibmc://192.168.122.1",
+			Type:     "ibmc",
+			Port:     "",
+			Host:     "192.168.122.1",
+			Hostname: "192.168.122.1",
+			Path:     "",
+		},
+
+		{
+			Scenario: "ibmc url path",
+			Address:  "ibmc://192.168.122.1:6233/foo",
+			Type:     "ibmc",
+			Port:     "6233",
+			Host:     "192.168.122.1",
+			Hostname: "192.168.122.1:6233",
+			Path:     "/foo",
+		},
+
+		{
+			Scenario: "ibmc url with http scheme",
+			Address:  "ibmc+http://192.168.122.1",
+			Type:     "ibmc+http",
+			Port:     "",
+			Host:     "192.168.122.1",
+			Hostname: "192.168.122.1",
+			Path:     "",
+		},
+
+		{
+			Scenario: "ibmc url with http scheme",
+			Address:  "ibmc+https://192.168.122.1",
+			Type:     "ibmc+https",
+			Port:     "",
+			Host:     "192.168.122.1",
+			Hostname: "192.168.122.1",
+			Path:     "",
+		},
+
+		{
+			Scenario: "ibmc url path",
+			Address:  "ibmc://192.168.122.1:6233/foo",
+			Type:     "ibmc",
+			Port:     "6233",
+			Host:     "192.168.122.1",
+			Hostname: "192.168.122.1:6233",
+			Path:     "/foo",
+		},
+
+		{
+			Scenario: "ibmc url ipv6",
+			Address:  "ibmc://[fe80::fc33:62ff:fe83:8a76]",
+			Type:     "ibmc",
+			Port:     "",
+			Host:     "fe80::fc33:62ff:fe83:8a76",
+			Hostname: "[fe80::fc33:62ff:fe83:8a76]",
+			Path:     "",
+		},
+
+		{
+			Scenario: "ibmc url path ipv6",
+			Address:  "ibmc://[fe80::fc33:62ff:fe83:8a76]:6233/foo",
+			Type:     "ibmc",
+			Port:     "6233",
+			Host:     "fe80::fc33:62ff:fe83:8a76",
+			Hostname: "[fe80::fc33:62ff:fe83:8a76]:6233",
+			Path:     "/foo",
+		},
+
+		{
+			Scenario: "ibmc url no sep",
+			Address:  "ibmc:192.168.122.1",
+			Type:     "ibmc",
+			Port:     "",
+			Host:     "192.168.122.1",
+			Hostname: "192.168.122.1",
+			Path:     "",
+		},
 	} {
 		t.Run(tc.Scenario, func(t *testing.T) {
 			url, err := getParsedURL(tc.Address)
@@ -372,6 +453,30 @@ func TestStaticDriverInfo(t *testing.T) {
 			vendor:     "",
 		},
 
+		{
+			Scenario:   "redfish virtual media HTTP",
+			input:      "redfish-virtualmedia+http://192.168.122.1",
+			needsMac:   true,
+			driver:     "redfish",
+			boot:       "redfish-virtual-media",
+			management: "",
+			power:      "",
+			raid:       "",
+			vendor:     "",
+		},
+
+		{
+			Scenario:   "redfish virtual media HTTPS",
+			input:      "redfish-virtualmedia+https://192.168.122.1",
+			needsMac:   true,
+			driver:     "redfish",
+			boot:       "redfish-virtual-media",
+			management: "",
+			power:      "",
+			raid:       "",
+			vendor:     "",
+		},
+
 		{
 			Scenario: "ilo5 virtual media",
 			input:    "ilo5-virtualmedia://192.168.122.1",
@@ -380,6 +485,22 @@ func TestStaticDriverInfo(t *testing.T) {
 			boot:     "redfish-virtual-media",
 		},
 
+		{
+			Scenario: "ilo5 virtual media HTTP",
+			input:    "ilo5-virtualmedia+http://192.168.122.1",
+			needsMac: true,
+			driver:   "redfish",
+			boot:     "redfish-virtual-media",
+		},
+
+		{
+			Scenario: "ilo5 virtual media HTTPS",
+			input:    "ilo5-virtualmedia+https://192.168.122.1",
+			needsMac: true,
+			driver:   "redfish",
+			boot:     "redfish-virtual-media",
+		},
+
 		{
 			Scenario:   "idrac virtual media",
 			input:      "idrac-virtualmedia://192.168.122.1",
@@ -391,6 +512,42 @@ func TestStaticDriverInfo(t *testing.T) {
 			raid:       "no-raid",
 			vendor:     "no-vendor",
 		},
+
+		{
+			Scenario:   "idrac virtual media HTTP",
+			input:      "idrac-virtualmedia+http://192.168.122.1",
+			needsMac:   true,
+			driver:     "idrac",
+			boot:       "idrac-redfish-virtual-media",
+			management: "idrac-redfish",
+			power:      "idrac-redfish",
+			raid:       "no-raid",
+			vendor:     "no-vendor",
+		},
+
+		{
+			Scenario:   "idrac virtual media HTTPS",
+			input:      "idrac-virtualmedia+https://192.168.122.1",
+			needsMac:   true,
+			driver:     "idrac",
+			boot:       "idrac-redfish-virtual-media",
+			management: "idrac-redfish",
+			power:      "idrac-redfish",
+			raid:       "no-raid",
+			vendor:     "no-vendor",
+		},
+
+		{
+			Scenario:   "ibmc",
+			input:      "ibmc://192.168.122.1:6233",
+			needsMac:   true,
+			driver:     "ibmc",
+			boot:       "pxe",
+			management: "ibmc",
+			power:      "ibmc",
+			raid:       "no-raid",
+			vendor:     "",
+		},
 	} {
 		t.Run(tc.Scenario, func(t *testing.T) {
 			acc, err := NewAccessDetails(tc.input, false)
@@ -655,6 +812,73 @@ func TestDriverInfo(t *testing.T) {
 				"redfish_verify_ca": false,
 			},
 		},
+
+		// ibmc driver testcases
+		{
+			Scenario: "ibmc",
+			input:    "ibmc://192.168.122.1/foo/bar",
+			expects: map[string]interface{}{
+				"ibmc_address":   "https://192.168.122.1/foo/bar",
+				"ibmc_password":  "",
+				"ibmc_username":  "",
+				"ibmc_verify_ca": false,
+			},
+		},
+
+		{
+			Scenario: "ibmc http",
+			input:    "ibmc+http://192.168.122.1/foo/bar",
+			expects: map[string]interface{}{
+				"ibmc_address":   "http://192.168.122.1/foo/bar",
+				"ibmc_password":  "",
+				"ibmc_username":  "",
+				"ibmc_verify_ca": false,
+			},
+		},
+
+		{
+			Scenario: "ibmc https",
+			input:    "ibmc+https://192.168.122.1/foo/bar",
+			expects: map[string]interface{}{
+				"ibmc_address":   "https://192.168.122.1/foo/bar",
+				"ibmc_password":  "",
+				"ibmc_username":  "",
+				"ibmc_verify_ca": false,
+			},
+		},
+
+		{
+			Scenario: "ibmc port",
+			input:    "ibmc://192.168.122.1:8080/foo/bar",
+			expects: map[string]interface{}{
+				"ibmc_address":   "https://192.168.122.1:8080/foo/bar",
+				"ibmc_password":  "",
+				"ibmc_username":  "",
+				"ibmc_verify_ca": false,
+			},
+		},
+
+		{
+			Scenario: "ibmc ipv6",
+			input:    "ibmc://[fe80::fc33:62ff:fe83:8a76]/foo/bar",
+			expects: map[string]interface{}{
+				"ibmc_address":   "https://[fe80::fc33:62ff:fe83:8a76]/foo/bar",
+				"ibmc_password":  "",
+				"ibmc_username":  "",
+				"ibmc_verify_ca": false,
+			},
+		},
+
+		{
+			Scenario: "ibmc ipv6 port",
+			input:    "ibmc://[fe80::fc33:62ff:fe83:8a76]:8080/foo",
+			expects: map[string]interface{}{
+				"ibmc_address":   "https://[fe80::fc33:62ff:fe83:8a76]:8080/foo",
+				"ibmc_password":  "",
+				"ibmc_username":  "",
+				"ibmc_verify_ca": false,
+			},
+		},
 	} {
 		t.Run(tc.Scenario, func(t *testing.T) {
 			acc, err := NewAccessDetails(tc.input, true)
